##  Editing Transformations
To edit a Transformation item, follow the instructions below:
  1. Hover over the transformation you want to edit, and you will see the Edit button appear at the top right corner.
  2. Click Edit.
  3. Make the necessary edits to the required fields, and then click Save to finalize the changes.
![Editing Transformations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742c7bb7a441014adac86c92ca498ee_LowRes.png)
Editing Transformations
